@@ -7,6 +7,7 @@
 #include "capplet-widget.h"
 #include <X11/Xlib.h>
 #include <assert.h>
+#include <locale.h>
 
 #include <gdk/gdkx.h>
 
@@ -127,11 +128,10 @@ mouse_apply (void)
 
         /* Ignore buttons above 3 -- these are assumed to be a wheel.
            If we have a non-wheeled mouse, this may do weird things */
-        max = MIN (mouse_nbuttons, 3);
+        XGetPointerMapping(GDK_DISPLAY (), buttons, MAX_BUTTONS);
+	max = MIN (mouse_nbuttons, 3);
         for (i = 0; i < max; ++i)
                 buttons[i] = mouse_rtol ? (max - i) : (i + 1);
-        for (; i < mouse_nbuttons; ++i)
-                buttons[i] = i + 1;
         XSetPointerMapping (GDK_DISPLAY (), buttons, mouse_nbuttons);
 
         if (mouse_acceleration < MAX_ACCEL)
@@ -339,6 +339,7 @@ main (int argc, char **argv)
         gchar *session_args[3];
         int token, init_results;
 
+				setlocale(LC_ALL, "");
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
