@@ -465,7 +465,7 @@ launch_miniview (screensaver_data *sd)
 void
 setup_callback (GtkWidget *widget, gpointer data)
 {
-        if (sd->dialog == NULL) {
+        if (sd && sd->dialog == NULL) {
                 gtk_widget_set_sensitive (setup_button, FALSE);
                 sd->dialog = make_dialog (sd);
         }
@@ -777,13 +777,13 @@ ok_callback (void)
 void
 page_hide_callback (void)
 {
-        if (sd->dialog)
+        if (sd && sd->dialog)
                 gtk_widget_hide (sd->dialog);
 }
 void
 page_show_callback (void)
 {
-        if (sd->dialog)
+        if (sd && sd->dialog)
                 gtk_widget_show (sd->dialog);
 }
 void
