@@ -10,6 +10,7 @@
 #include <stdarg.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <locale.h>
 #include <gtk/gtk.h>
 #include "capplet-widget.h"
 #include <gnome.h>
@@ -85,6 +86,7 @@ main(int argc, char *argv[])
     int token, init_results;
     SoundProps *sound_properties;
 
+		setlocale(LC_ALL, "");
     bindtextdomain (PACKAGE, GNOMELOCALEDIR);
     textdomain (PACKAGE);
 
