@@ -6,6 +6,7 @@
  */
 #include <ctype.h>
 #include <config.h>
+#include <locale.h>
 #include "wm-properties.h"
 #include "capplet-widget.h"
 #include <gnome.h>
@@ -1121,6 +1122,7 @@ main (int argc, char **argv)
 {
         gint init_results;
 
+				setlocale(LC_ALL, "");
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
