@@ -24,23 +24,26 @@ create_templist (node_data *data, GList **list)
         if (data->modified == TRUE)
                 *list = (g_list_prepend (*list, data));
 }
-void
+int
 exit_callback(GtkWidget *widget, gpointer data) 
 {
         GList* templist = NULL;
         
-        if (exit_dialog)
-                gnome_dialog_close (GNOME_DIALOG (exit_dialog));
+        if (exit_dialog != NULL) {
+		destroying = TRUE;
+		gnome_dialog_close (GNOME_DIALOG (exit_dialog));
+	}
 
         g_list_foreach (capplet_list, create_templist, &templist);
 
         if (!templist) {
                 gtk_widget_destroy (main_window);
                 control_center_corba_gtk_main_quit();
-                return;
+                return FALSE;
         }                
         exit_dialog = create_exit_dialog(templist);
         gtk_widget_show(GTK_WIDGET(exit_dialog));
+				return TRUE;
 }
 void
 exit_dialog_ok_callback(GtkWidget *widget, gpointer data)
@@ -64,21 +67,11 @@ exit_dialog_close_callback(GtkWidget *widget, gpointer data)
 void
 help_callback (GtkWidget *widget, gpointer data)
 {
-        gchar *tmp;
-        tmp = gnome_help_file_find_file ("control-center", "index.html");
-        if (tmp) {
-                gnome_help_goto(0, tmp);
-                g_free(tmp);
-        } else {
-                GtkWidget *mbox;
-
-                mbox = gnome_message_box_new(_("No help is available/installed. Please make sure you\nhave the GNOME User's Guide installed on your system."),
-                                             GNOME_MESSAGE_BOX_ERROR,
-                                             _("Close"), NULL);
-
-                gtk_widget_show(mbox);
-        }
+        GnomeHelpMenuEntry entry;
 
+        entry.name = "control-center";
+        entry.path = "index.html";
+        gnome_help_display(0, &entry);
 }
 
 void
