@@ -156,6 +156,7 @@ capplet_widget_init (CappletWidget *widget)
         gtk_signal_connect (GTK_OBJECT (widget), "destroy",
                             (GtkSignalFunc) capplet_close_callback, NULL);
         widget->changed = FALSE;
+        widget->immediate = FALSE;
 }
 GtkWidget *
 capplet_widget_new ()
@@ -191,6 +192,15 @@ capplet_widget_state_changed(CappletWidget *cap, gboolean undoable)
                 cap->changed = TRUE;
         }
 }
+void
+capplet_widget_changes_are_immediate(CappletWidget *cap)
+{
+        if (cap->immediate == FALSE) {
+                capplet_corba_changes_are_immediate (cap->control_center_id);
+                cap->immediate = TRUE;
+        }
+}
+
 /* non widget calls */
 void
 capplet_gtk_main (void)
